Statemachine Module
-------------------

.. automodule:: lewis.core.statemachine
    :members: StateMachineException, HasContext, State

.. autoclass:: lewis.core.statemachine.Transition
    :members:
    :special-members:

.. autoclass:: lewis.core.statemachine.StateMachine
    :members:
